@@ -14,7 +14,7 @@ import secrets
 import struct
 import time
 from random import randint
-from typing import Any, Callable, Coroutine, Optional
+from typing import Any, Callable, Coroutine, Mapping, Optional
 
 import aiohttp
 from Crypto.Cipher import AES
@@ -85,8 +85,8 @@ class PreparedRequest:
 
 
 class RoborockClient:
-    def __init__(self, endpoint: str, device_info: RoborockDeviceInfo) -> None:
-        self.device_info = device_info
+    def __init__(self, endpoint: str, devices_info: Mapping[str, RoborockDeviceInfo]) -> None:
+        self.devices_info = devices_info
         self._endpoint = endpoint
         self._nonce = secrets.token_bytes(16)
         self._waiting_queue: dict[int, RoborockFuture] = {}
@@ -200,27 +200,27 @@ class RoborockClient:
         )
         return request_id, timestamp, payload
 
-    async def send_command(self, method: RoborockCommand, params: Optional[list] = None):
+    async def send_command(self, device_id: str, method: RoborockCommand, params: Optional[list] = None):
         raise NotImplementedError
 
-    async def get_status(self) -> Status | None:
-        status = await self.send_command(RoborockCommand.GET_STATUS)
+    async def get_status(self, device_id: str) -> Status | None:
+        status = await self.send_command(device_id, RoborockCommand.GET_STATUS)
         if isinstance(status, dict):
             return Status.from_dict(status)
         return None
 
-    async def get_dnd_timer(self) -> DNDTimer | None:
+    async def get_dnd_timer(self, device_id: str) -> DNDTimer | None:
         try:
-            dnd_timer = await self.send_command(RoborockCommand.GET_DND_TIMER)
+            dnd_timer = await self.send_command(device_id, RoborockCommand.GET_DND_TIMER)
             if isinstance(dnd_timer, dict):
                 return DNDTimer.from_dict(dnd_timer)
         except RoborockTimeout as e:
             _LOGGER.error(e)
         return None
 
-    async def get_clean_summary(self) -> CleanSummary | None:
+    async def get_clean_summary(self, device_id: str) -> CleanSummary | None:
         try:
-            clean_summary = await self.send_command(RoborockCommand.GET_CLEAN_SUMMARY)
+            clean_summary = await self.send_command(device_id, RoborockCommand.GET_CLEAN_SUMMARY)
             if isinstance(clean_summary, dict):
                 return CleanSummary.from_dict(clean_summary)
             elif isinstance(clean_summary, list):
@@ -232,54 +232,55 @@ class RoborockClient:
             _LOGGER.error(e)
         return None
 
-    async def get_clean_record(self, record_id: int) -> CleanRecord | None:
+    async def get_clean_record(self, device_id: str, record_id: int) -> CleanRecord | None:
         try:
-            clean_record = await self.send_command(RoborockCommand.GET_CLEAN_RECORD, [record_id])
+            clean_record = await self.send_command(device_id, RoborockCommand.GET_CLEAN_RECORD, [record_id])
             if isinstance(clean_record, dict):
                 return CleanRecord.from_dict(clean_record)
         except RoborockTimeout as e:
             _LOGGER.error(e)
         return None
 
-    async def get_consumable(self) -> Consumable | None:
+    async def get_consumable(self, device_id: str) -> Consumable | None:
         try:
-            consumable = await self.send_command(RoborockCommand.GET_CONSUMABLE)
+            consumable = await self.send_command(device_id, RoborockCommand.GET_CONSUMABLE)
             if isinstance(consumable, dict):
                 return Consumable.from_dict(consumable)
         except RoborockTimeout as e:
             _LOGGER.error(e)
         return None
 
-    async def get_wash_towel_mode(self) -> WashTowelMode | None:
+    async def get_wash_towel_mode(self, device_id: str) -> WashTowelMode | None:
         try:
-            washing_mode = await self.send_command(RoborockCommand.GET_WASH_TOWEL_MODE)
+            washing_mode = await self.send_command(device_id, RoborockCommand.GET_WASH_TOWEL_MODE)
             if isinstance(washing_mode, dict):
                 return WashTowelMode.from_dict(washing_mode)
         except RoborockTimeout as e:
             _LOGGER.error(e)
         return None
 
-    async def get_dust_collection_mode(self) -> DustCollectionMode | None:
+    async def get_dust_collection_mode(self, device_id: str) -> DustCollectionMode | None:
         try:
-            dust_collection = await self.send_command(RoborockCommand.GET_DUST_COLLECTION_MODE)
+            dust_collection = await self.send_command(device_id, RoborockCommand.GET_DUST_COLLECTION_MODE)
             if isinstance(dust_collection, dict):
                 return DustCollectionMode.from_dict(dust_collection)
         except RoborockTimeout as e:
             _LOGGER.error(e)
         return None
 
-    async def get_smart_wash_params(self) -> SmartWashParams | None:
+    async def get_smart_wash_params(self, device_id: str) -> SmartWashParams | None:
         try:
-            mop_wash_mode = await self.send_command(RoborockCommand.GET_SMART_WASH_PARAMS)
+            mop_wash_mode = await self.send_command(device_id, RoborockCommand.GET_SMART_WASH_PARAMS)
             if isinstance(mop_wash_mode, dict):
                 return SmartWashParams.from_dict(mop_wash_mode)
         except RoborockTimeout as e:
             _LOGGER.error(e)
         return None
 
-    async def get_dock_summary(self, dock_type: RoborockEnum) -> DockSummary | None:
+    async def get_dock_summary(self, device_id: str, dock_type: RoborockEnum) -> DockSummary | None:
         """Gets the status summary from the dock with the methods available for a given dock.
 
+        :param device_id: Device id
         :param dock_type: RoborockDockTypeCode"""
         try:
             commands: list[
@@ -288,11 +289,11 @@ class RoborockClient:
                     Any,
                     DustCollectionMode | WashTowelMode | SmartWashParams | None,
                 ]
-            ] = [self.get_dust_collection_mode()]
+            ] = [self.get_dust_collection_mode(device_id)]
             if dock_type == RoborockDockTypeCode["3"]:
                 commands += [
-                    self.get_wash_towel_mode(),
-                    self.get_smart_wash_params(),
+                    self.get_wash_towel_mode(device_id),
+                    self.get_smart_wash_params(device_id),
                 ]
             [dust_collection_mode, wash_towel_mode, smart_wash_params] = unpack_list(
                 list(await asyncio.gather(*commands)), 3
@@ -303,21 +304,21 @@ class RoborockClient:
             _LOGGER.error(e)
         return None
 
-    async def get_prop(self) -> DeviceProp | None:
+    async def get_prop(self, device_id: str) -> DeviceProp | None:
         [status, dnd_timer, clean_summary, consumable] = await asyncio.gather(
             *[
-                self.get_status(),
-                self.get_dnd_timer(),
-                self.get_clean_summary(),
-                self.get_consumable(),
+                self.get_status(device_id),
+                self.get_dnd_timer(device_id),
+                self.get_clean_summary(device_id),
+                self.get_consumable(device_id),
             ]
         )
         last_clean_record = None
         if clean_summary and clean_summary.records and len(clean_summary.records) > 0:
-            last_clean_record = await self.get_clean_record(clean_summary.records[0])
+            last_clean_record = await self.get_clean_record(device_id, clean_summary.records[0])
         dock_summary = None
         if status and status.dock_type is not None and status.dock_type != RoborockDockTypeCode["0"]:
-            dock_summary = await self.get_dock_summary(status.dock_type)
+            dock_summary = await self.get_dock_summary(device_id, status.dock_type)
         if any([status, dnd_timer, clean_summary, consumable]):
             return DeviceProp(
                 status,
@@ -329,27 +330,27 @@ class RoborockClient:
             )
         return None
 
-    async def get_multi_maps_list(self) -> MultiMapsList | None:
+    async def get_multi_maps_list(self, device_id) -> MultiMapsList | None:
         try:
-            multi_maps_list = await self.send_command(RoborockCommand.GET_MULTI_MAPS_LIST)
+            multi_maps_list = await self.send_command(device_id, RoborockCommand.GET_MULTI_MAPS_LIST)
             if isinstance(multi_maps_list, dict):
                 return MultiMapsList.from_dict(multi_maps_list)
         except RoborockTimeout as e:
             _LOGGER.error(e)
         return None
 
-    async def get_networking(self) -> NetworkInfo | None:
+    async def get_networking(self, device_id) -> NetworkInfo | None:
         try:
-            networking_info = await self.send_command(RoborockCommand.GET_NETWORK_INFO)
+            networking_info = await self.send_command(device_id, RoborockCommand.GET_NETWORK_INFO)
             if isinstance(networking_info, dict):
                 return NetworkInfo.from_dict(networking_info)
         except RoborockTimeout as e:
             _LOGGER.error(e)
         return None
 
-    async def get_room_mapping(self) -> list[RoomMapping]:
+    async def get_room_mapping(self, device_id: str) -> list[RoomMapping]:
         """Gets the mapping from segment id -> iot id. Only works on local api."""
-        mapping = await self.send_command(RoborockCommand.GET_ROOM_MAPPING)
+        mapping = await self.send_command(device_id, RoborockCommand.GET_ROOM_MAPPING)
         if isinstance(mapping, list):
             return [
                 RoomMapping(segment_id=segment_id, iot_id=iot_id)  # type: ignore
